@@ -1,7 +1,7 @@
 package HTTP::Session;
 use Moose;
 use 5.00800;
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 use Digest::SHA1 ();
 use Time::HiRes ();
 use Moose::Util::TypeConstraints;
@@ -137,15 +137,6 @@ sub remove {
     delete $self->_data->{$key};
 }
 
-sub remove_all {
-    my $self = shift;
-
-    $self->is_changed(1);
-    for my $key ( CORE::keys %{$self->_data} ) {
-        delete $self->_data->{$key};
-    }
-}
-
 sub as_hashref {
     my $self = shift;
     return { %{ $self->_data } }; # shallow copy
@@ -267,10 +258,6 @@ set session item
 
 remove item.
 
-=item $session->remove_all()
-
-remove whole items
-
 =item $session->as_hashref()
 
 session as hashref.
